Changelog
=========


(unreleased)
------------
- MacOS compatibility. [KK]
- Cleanups. [Krzysztof]
- Ignore notebooks dir. [Krzysztof]
- Batch long prompts. [Krzysztof]
- Fix version file. [KK]
- Release: version  🚀 [KK]
- Fix version. [KK]
- Release: version  🚀 [KK]
- Add potential fix for macOS. [KK]


1.6.0 (2024-12-04)
------------------
- Release: version 1.6.0 🚀 [Krzysztof]
- Release: version 1.5.0 🚀 [Krzysztof]
- Quick change. [Krzysztof]
- Add support for running async functions. [Krzysztof]


1.5.0 (2024-10-19)
------------------
- Release: version 1.5.0 🚀 [Krzysztof]
- Improve Variable search pattern. [Krzysztof]
- Add notebook with IPython Magics usage. [Krzysztof]
- Add REPL Ipython Magics functionalities. [Krzysztof]


1.4.0 (2024-10-18)
------------------
- Release: version 1.4.0 🚀 [Krzysztof]
- Add multiple fixes. [Krzysztof]

  Add fix for parsing Variables from REPL output with space in the dtype
  Allow to get Variable by name even if it's not registered in the repl register
- Quick change. [Krzysztof]
- Quick change. [Krzysztof]
- Quick change. [Krzysztof]
- Quick change. [Krzysztof]


1.3.0 (2024-10-12)
------------------
- Release: version 1.3.0 🚀 [Krzysztof]
- Fix release script. [Krzysztof]
- Fix version file. [Krzysztof]


1.2.0 (2024-10-12)
------------------
- Update documentation. [Krzysztof]
- Refactors. [Krzysztof]
- Refactors. [Krzysztof]
- Minor changes. [Krzysztof]
- Code cleanup and simple tests. [Krzysztof]
- Refactors. [Krzysztof]
- Refactors. [Krzysztof]
- Add minor changes. [Krzysztof]
- Quick change. [Krzysztof]
- Add line profiler. [Krzysztof]


1.1.1 (2024-09-30)
------------------
- Release: version 1.1.1 🚀 [Krzysztof]
- Merge pull request #7 from kmkolasinski/feature-use-json-file-for-
  serialization. [Krzysztof Kolasinski]

  Add fixes for python - swift communitation
- Quick change. [Krzysztof]
- Add fixes for python - swift communitation. [Krzysztof]


1.0.1 (2024-09-29)
------------------
- Release: version 1.0.1 🚀 [Krzysztof]
- Release: version 1.0.0 🚀 [Krzysztof]
- Merge branch 'main' of github.com:kmkolasinski/repltilian. [Krzysztof]
- Merge pull request #6 from kmkolasinski/feature-initial-code.
  [Krzysztof Kolasinski]

  Initial code for swift repl interation
- Quick change. [Krzysztof]
- Refactors. [Krzysztof]
- Initial code for swift repl interation. [Krzysztof]


1.0.0 (2024-09-29)
------------------
- Release: version 1.0.0 🚀 [Krzysztof]
- Merge pull request #3 from
  kmkolasinski/dependabot/github_actions/actions/checkout-4. [Krzysztof
  Kolasinski]

  Bump actions/checkout from 3 to 4
- Bump actions/checkout from 3 to 4. [dependabot[bot]]

  Bumps [actions/checkout](https://github.com/actions/checkout) from 3 to 4.
  - [Release notes](https://github.com/actions/checkout/releases)
  - [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/actions/checkout/compare/v3...v4)

  ---
  updated-dependencies:
  - dependency-name: actions/checkout
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #2 from
  kmkolasinski/dependabot/github_actions/softprops/action-gh-release-2.
  [Krzysztof Kolasinski]

  Bump softprops/action-gh-release from 1 to 2
- Bump softprops/action-gh-release from 1 to 2. [dependabot[bot]]

  Bumps [softprops/action-gh-release](https://github.com/softprops/action-gh-release) from 1 to 2.
  - [Release notes](https://github.com/softprops/action-gh-release/releases)
  - [Changelog](https://github.com/softprops/action-gh-release/blob/master/CHANGELOG.md)
  - [Commits](https://github.com/softprops/action-gh-release/compare/v1...v2)

  ---
  updated-dependencies:
  - dependency-name: softprops/action-gh-release
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #1 from
  kmkolasinski/dependabot/github_actions/stefanzweifel/git-auto-commit-
  action-5. [Krzysztof Kolasinski]

  Bump stefanzweifel/git-auto-commit-action from 4 to 5
- Bump stefanzweifel/git-auto-commit-action from 4 to 5.
  [dependabot[bot]]

  Bumps [stefanzweifel/git-auto-commit-action](https://github.com/stefanzweifel/git-auto-commit-action) from 4 to 5.
  - [Release notes](https://github.com/stefanzweifel/git-auto-commit-action/releases)
  - [Changelog](https://github.com/stefanzweifel/git-auto-commit-action/blob/master/CHANGELOG.md)
  - [Commits](https://github.com/stefanzweifel/git-auto-commit-action/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: stefanzweifel/git-auto-commit-action
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #4 from
  kmkolasinski/dependabot/github_actions/actions/setup-python-5.
  [Krzysztof Kolasinski]

  Bump actions/setup-python from 4 to 5
- Bump actions/setup-python from 4 to 5. [dependabot[bot]]

  Bumps [actions/setup-python](https://github.com/actions/setup-python) from 4 to 5.
  - [Release notes](https://github.com/actions/setup-python/releases)
  - [Commits](https://github.com/actions/setup-python/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: actions/setup-python
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #5 from
  kmkolasinski/dependabot/github_actions/codecov/codecov-action-4.
  [Krzysztof Kolasinski]

  Bump codecov/codecov-action from 3 to 4
- Bump codecov/codecov-action from 3 to 4. [dependabot[bot]]

  Bumps [codecov/codecov-action](https://github.com/codecov/codecov-action) from 3 to 4.
  - [Release notes](https://github.com/codecov/codecov-action/releases)
  - [Changelog](https://github.com/codecov/codecov-action/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/codecov/codecov-action/compare/v3...v4)

  ---
  updated-dependencies:
  - dependency-name: codecov/codecov-action
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- ✅ Ready to clone and code. [kmkolasinski]
- Initial commit. [Krzysztof Kolasinski]


